@@ -13,6 +13,6 @@
 Facter.add(:lsbdistid) do
   confine :kernel => [ :linux, :"gnu/kfreebsd" ]
   setcode do
-    Facter::Util::Resolution.exec('lsb_release -i -s')
+    Facter::Util::Resolution.exec('lsb_release -i -s 2>/dev/null')
   end
 end
