@@ -16,14 +16,18 @@ Facter.add(:osfamily) do
 
   setcode do
     case Facter.value(:operatingsystem)
-    when "RedHat", "Fedora", "CentOS", "Scientific", "SLC", "Ascendos", "CloudLinux", "PSBM", "OracleLinux", "OVS", "OEL"
+    when "RedHat", "Fedora", "CentOS", "Scientific", "SLC", "Ascendos", "CloudLinux", "PSBM", "OracleLinux", "OVS", "OEL", "Amazon", "XenServer"
       "RedHat"
     when "Ubuntu", "Debian"
       "Debian"
     when "SLES", "SLED", "OpenSuSE", "SuSE"
       "Suse"
-    when "Solaris", "Nexenta"
+    when "Solaris", "Nexenta", "OmniOS", "OpenIndiana", "SmartOS"
       "Solaris"
+    when "Gentoo"
+      "Gentoo"
+    when "Archlinux"
+      "Archlinux"
     else
       Facter.value("kernel")
     end
