@@ -14,6 +14,11 @@ Facter.add(:ps) do
   setcode do 'ps -ef' end
 end
 
+Facter.add(:ps) do
+  confine :operatingsystem => :OpenWrt
+  setcode do 'ps www' end
+end
+
 Facter.add(:ps) do
   confine :operatingsystem => %w{FreeBSD NetBSD OpenBSD Darwin DragonFly}
   setcode do 'ps auxwww' end
