@@ -67,6 +67,14 @@ module Facter::Memory
     freemem = ( memfree + memspecfree ) * pagesize
   end
 
+  # on AIX use svmon to get the free memory:
+  # it's the third value on the line starting with memory
+  # svmon can be run by non root users
+  def self.svmon_aix_find_free_memory()
+    Facter::Util::Resolution.exec("/usr/bin/svmon -O unit=KB") =~ /^memory\s+\d+\s+\d+\s+(\d+)\s+/
+    $1
+  end
+
   def self.mem_free(kernel = Facter.value(:kernel))
     output = mem_free_info(kernel)
     scale_mem_free_value output, kernel
@@ -80,12 +88,14 @@ module Facter::Memory
       vmstat_find_free_memory(["-H"])
     when /Darwin/i
       vmstat_darwin_find_free_memory()
+    when /AIX/i
+      svmon_aix_find_free_memory()
     end
   end
 
   def self.scale_mem_free_value (value, kernel)
     case kernel
-    when /OpenBSD/i, /FreeBSD/i, /SunOS/i, /Dragonfly/i
+    when /OpenBSD/i, /FreeBSD/i, /SunOS/i, /Dragonfly/i, /AIX/i
       value.to_f / 1024.0
     when /Darwin/i
       value.to_f / 1024.0 / 1024.0
@@ -109,6 +119,10 @@ module Facter::Memory
       Facter::Util::Resolution.exec("sysctl -n hw.memsize")
     when /Dragonfly/i
       Facter::Util::Resolution.exec("sysctl -n hw.physmem")
+    when /AIX/i
+      if Facter::Util::Resolution.exec("/usr/bin/svmon -O unit=KB") =~ /^memory\s+(\d+)\s+/
+        $1
+      end
     end
   end
 
@@ -116,6 +130,8 @@ module Facter::Memory
     case kernel
     when /OpenBSD/i, /FreeBSD/i, /Darwin/i, /Dragonfly/i
       value.to_f / 1024.0 / 1024.0
+    when /AIX/i
+      value.to_f / 1024.0
     else
       value.to_f
     end
@@ -134,7 +150,7 @@ module Facter::Memory
   def self.swap_info(kernel = Facter.value(:kernel))
     case kernel
     when /AIX/i
-      (Facter.value(:id) == "root") ? Facter::Util::Resolution.exec('swap -l') : nil
+      (Facter.value(:id) == "root") ? Facter::Util::Resolution.exec('swap -l 2>/dev/null') : nil
     when /OpenBSD/i
       Facter::Util::Resolution.exec('swapctl -s')
     when /FreeBSD/i
@@ -142,7 +158,7 @@ module Facter::Memory
     when /Darwin/i
       Facter::Util::Resolution.exec('sysctl vm.swapusage')
     when /SunOS/i
-      Facter::Util::Resolution.exec('/usr/sbin/swap -l')
+      Facter::Util::Resolution.exec('/usr/sbin/swap -l 2>/dev/null')
     end
   end
 
