@@ -87,6 +87,8 @@ module Processor
         elsif line.match(/\d+\s+((?:PA-RISC|Intel).*processors.*)/) then
           cpu = $1.to_s
           cpu.sub!(/processors/, "processor")
+        elsif line.match(/\s+(Intel.*Processor.*)/) then
+          cpu = $1.to_s
         end
       end
     end
@@ -218,55 +220,47 @@ module Processor
       model = Facter.value(:architecture)
       case model
       when "x86_64", "amd64", "i386", "x86", /parisc/, "hppa", "ia64"
-        Thread::exclusive do
-          File.readlines(cpuinfo).each do |l|
-            if l =~ /processor\s+:\s+(\d+)/
-              processor_num = $1.to_i
-            elsif l =~ /model name\s+:\s+(.*)\s*$/
-              processor_list[processor_num] = $1 unless processor_num == -1
-              processor_num = -1
-            elsif l =~ /processor\s+(\d+):\s+(.*)/
-              processor_num = $1.to_i
-              processor_list[processor_num] = $2 unless processor_num == -1
-            end
+        File.readlines(cpuinfo).each do |l|
+          if l =~ /processor\s+:\s+(\d+)/
+            processor_num = $1.to_i
+          elsif l =~ /model name\s+:\s+(.*)\s*$/
+            processor_list[processor_num] = $1 unless processor_num == -1
+            processor_num = -1
+          elsif l =~ /processor\s+(\d+):\s+(.*)/
+            processor_num = $1.to_i
+            processor_list[processor_num] = $2 unless processor_num == -1
           end
         end
 
       when "ppc64"
-        Thread::exclusive do
-          File.readlines(cpuinfo).each do |l|
-            if l =~ /processor\s+:\s+(\d+)/
-              processor_num = $1.to_i
-            elsif l =~ /cpu\s+:\s+(.*)\s*$/
-              processor_list[processor_num] = $1 unless processor_num == -1
-              processor_num = -1
-            end
+        File.readlines(cpuinfo).each do |l|
+          if l =~ /processor\s+:\s+(\d+)/
+            processor_num = $1.to_i
+          elsif l =~ /cpu\s+:\s+(.*)\s*$/
+            processor_list[processor_num] = $1 unless processor_num == -1
+            processor_num = -1
           end
         end
 
       when /arm/
-        Thread::exclusive do
-          File.readlines(cpuinfo).each do |l|
-            if l =~ /Processor\s+:\s+(.+)/
+        File.readlines(cpuinfo).each do |l|
+          if l =~ /Processor\s+:\s+(.+)/
+            processor_num += 1
+            processor_list[processor_num] = $1.chomp
+          elsif l =~ /processor\s+:\s+(\d+)\s*$/
+            proc_num = $1.to_i
+            if proc_num != 0
               processor_num += 1
-              processor_list[processor_num] = $1.chomp
-            elsif l =~ /processor\s+:\s+(\d+)\s*$/
-              proc_num = $1.to_i
-              if proc_num != 0
-                processor_num += 1
-                processor_list[processor_num] = processor_list[processor_num-1]
-              end
+              processor_list[processor_num] = processor_list[processor_num-1]
             end
           end
         end
 
       when /sparc/
-        Thread::exclusive do
-          File.readlines(cpuinfo).each do |l|
-            if l =~ /cpu\s+:\s+(.*)\s*$/
-              processor_num += 1
-              processor_list[processor_num] = $1
-            end
+        File.readlines(cpuinfo).each do |l|
+          if l =~ /cpu\s+:\s+(.*)\s*$/
+            processor_num += 1
+            processor_list[processor_num] = $1
           end
         end
       end
