@@ -1,10 +1,27 @@
+require 'facter/util/file_read'
+
 module Facter::Util::Virtual
   ##
   # virt_what is a delegating helper method intended to make it easier to stub
   # the system call without affecting other calls to
   # Facter::Util::Resolution.exec
+  #
+  # Per https://bugzilla.redhat.com/show_bug.cgi?id=719611 when run as a
+  # non-root user the virt-what command may emit an error message on stdout,
+  # and later versions of virt-what may emit this message on stderr. This
+  # method ensures stderr is redirected and that error messages are stripped
+  # from stdout.
   def self.virt_what(command = "virt-what")
-    Facter::Util::Resolution.exec command
+    command = Facter::Util::Resolution.which(command)
+    return unless command
+
+    if Facter.value(:kernel) == 'windows'
+      redirected_cmd = "#{command} 2>NUL"
+    else
+      redirected_cmd = "#{command} 2>/dev/null"
+    end
+    output = Facter::Util::Resolution.exec redirected_cmd
+    output.gsub(/^virt-what: .*$/, '') if output
   end
 
   ##
@@ -47,6 +64,10 @@ module Facter::Util::Virtual
   def self.vserver?
     return false unless FileTest.exists?("/proc/self/status")
     txt = File.open("/proc/self/status", "rb").read
+    if txt.respond_to?(:encode!)
+      txt.encode!('UTF-16', 'UTF-8', :invalid => :replace)
+      txt.encode!('UTF-8', 'UTF-16')
+    end
     return true if txt =~ /^(s_context|VxID):[[:blank:]]*[0-9]/
     return false
   end
@@ -124,7 +145,7 @@ module Facter::Util::Virtual
   # @return [String] or nil if the path does not exist
   def self.read_sysfs_dmi_entries(path="/sys/firmware/dmi/entries/1-0/raw")
     if File.exists?(path)
-      File.read(path)
+      Facter::Util::FileRead.read_binary(path)
     end
   end
 end
