@@ -136,8 +136,8 @@ describe "ec2 facts" do
     end
 
     it "should return nil if open fails" do
+      Facter.stubs(:warn) # do not pollute test output
       Facter.expects(:warn).with('Could not retrieve ec2 metadata: host unreachable')
-      Facter::Util::Resolution.any_instance.stubs(:warn) # do not pollute test output
 
       Object.any_instance.expects(:open).
         with("#{api_prefix}/2008-02-01/meta-data/").
