@@ -102,13 +102,13 @@ describe Facter do
     end
   end
 
-  describe Facter[:hostname] do
+  describe "Facter[:hostname]" do
     it "should have its ldapname set to 'cn'" do
       Facter[:hostname].ldapname.should == "cn"
     end
   end
 
-  describe Facter[:ipaddress] do
+  describe "Facter[:ipaddress]" do
     it "should have its ldapname set to 'iphostnumber'" do
       Facter[:ipaddress].ldapname.should == "iphostnumber"
     end
