@@ -154,7 +154,21 @@ device maj,min total free
 /dev/hd6 10, 2 512MB 508MB
 SWAP
 
-      Facter::Util::Resolution.stubs(:exec).with('swap -l').returns(swapusage)
+      Facter::Util::Resolution.stubs(:exec).with('swap -l 2>/dev/null').returns(swapusage)
+
+      svmon = <<SVMON
+Unit: KB
+--------------------------------------------------------------------------------------
+               size       inuse        free         pin     virtual  available   mmode
+memory     32768000     9948408    22819592     2432080     4448928   27231828     Ded
+pg space   34078720       15000
+
+               work        pers        clnt       other
+pin         1478228           0           0      953852
+in use      4448928           0     5499480
+SVMON
+
+      Facter::Util::Resolution.stubs(:exec).with('/usr/bin/svmon -O unit=KB').returns(svmon)
 
       Facter.collection.internal_loader.load(:memory)
     end
@@ -190,6 +204,15 @@ SWAP
         Facter.fact(:swapfree_mb).value.should == "508.00"
       end
     end
+
+    it "should return the current memory free in MB" do
+      Facter.fact(:memoryfree_mb).value.should == "22284.76"
+    end
+
+    it "should return the current memory size in MB" do
+      Facter.fact(:memorysize_mb).value.should == "32000.00"
+    end
+
   end
 
 
@@ -264,7 +287,7 @@ VMSTAT
 swapfile             dev  swaplo blocks   free
 /dev/swap           4294967295,4294967295     16 2097136 2097136
 SWAP
-        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l').returns sample_swap_line
+        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns sample_swap_line
 
         Facter.collection.internal_loader.load(:memory)
       end
@@ -293,7 +316,7 @@ swapfile             dev  swaplo blocks   free
 /dev/swap           4294967295,4294967295     16 2097136 2097136
 /dev/swap2          4294967295,4294967295     16 2097136 2097136
 SWAP
-        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l').returns sample_swap_line
+        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns sample_swap_line
         Facter.collection.internal_loader.load(:memory)
       end
 
@@ -316,7 +339,7 @@ SWAP
 
     describe "when no swap exists" do
       before(:each) do
-        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l').returns ""
+        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns ""
 
         Facter.collection.internal_loader.load(:memory)
       end
