@@ -81,19 +81,61 @@ describe "Darwin", :unless => Facter::Util::Config.is_windows? do
   end
 end
 
-describe "Windows" do
-  it "should return the first macaddress" do
-    Facter.fact(:kernel).stubs(:value).returns("windows")
-
-    nic = stubs 'nic'
-    nic.stubs(:MacAddress).returns("00:0C:29:0C:9E:9F")
-
-    nic2 = stubs 'nic'
-    nic2.stubs(:MacAddress).returns("00:0C:29:0C:9E:AF")
-
+describe "The macaddress fact" do
+  context "on Windows" do
     require 'facter/util/wmi'
-    Facter::Util::WMI.stubs(:execquery).with("select MACAddress from Win32_NetworkAdapterConfiguration where IPEnabled = True").returns([nic, nic2])
+    require 'facter/util/registry'
+    require 'facter_spec/windows_network'
 
-    Facter.fact(:macaddress).value.should == "00:0C:29:0C:9E:9F"
+    include FacterSpec::WindowsNetwork
+
+    before :each do
+      Facter.fact(:kernel).stubs(:value).returns(:windows)
+      Facter::Util::Registry.stubs(:hklm_read).returns(nic_bindings)
+    end
+
+    describe "when you have no active network adapter" do
+      it "should return nil if there are no active (or any) network adapters" do
+        Facter::Util::WMI.expects(:execquery).returns([])
+
+        Facter.value(:macaddress).should == nil
+      end
+    end
+
+    describe "when you have one network adapter" do
+      it "should return properly" do
+        nic = given_a_valid_windows_nic_with_ipv4_and_ipv6
+        Facter::Util::WMI.expects(:execquery).returns([nic])
+
+        Facter.value(:macaddress).should == macAddress0
+      end
+    end
+
+    describe "when you have more than one network adapter" do
+      it "should return the macaddress of the adapter with the lowest IP connection metric (best connection)" do
+        nics = given_two_valid_windows_nics_with_ipv4_and_ipv6
+        nics[:nic1].expects(:IPConnectionMetric).returns(5)
+        Facter::Util::WMI.expects(:execquery).returns(nics.values)
+
+        Facter.value(:macaddress).should == macAddress1
+      end
+
+      context "when the IP connection metric is the same" do
+        it "should return the macaddress of the adapter with the lowest binding order" do
+          nics = given_two_valid_windows_nics_with_ipv4_and_ipv6
+          Facter::Util::WMI.expects(:execquery).returns(nics.values)
+
+          Facter.value(:macaddress).should == macAddress0
+        end
+
+        it "should return the macaddress of the adapter with the lowest MACAddress when multiple adapters have the same IP connection metric when the lowest MACAddress is not first" do
+          nics = given_two_valid_windows_nics_with_ipv4_and_ipv6
+          Facter::Util::WMI.expects(:execquery).returns(nics.values)
+          Facter::Util::Registry.stubs(:hklm_read).returns(["\\Device\\#{settingId1}", "\\Device\\#{settingId0}" ])
+
+          Facter.value(:macaddress).should == macAddress1
+        end
+      end
+    end
   end
 end
