@@ -42,8 +42,10 @@ describe Facter::Util::Macosx do
   end
 
   it 'should fail when trying to read invalid XML' do
-    expect { Facter::Util::Macosx.intern_xml('<bad}|%-->xml<--->') }.to \
-      raise_error(RuntimeError, /A plist file could not be properly read by Facter::Util::CFPropertyList/)
+    STDERR.stubs(:<<)
+    expect {
+      Facter::Util::Macosx.intern_xml('<bad}|%-->xml<--->')
+    }.to raise_error(RuntimeError, /A plist file could not be properly read by Facter::Util::CFPropertyList/)
   end
 
   describe "when collecting profiler data" do
