@@ -34,8 +34,9 @@ describe Facter::Manufacturer do
   it "should not set manufacturer if prtdiag output is nil" do
     # Stub kernel so we don't have windows fall through to its own mechanism
     Facter.fact(:kernel).stubs(:value).returns("SunOS")
+    Facter.fact(:hardwareisa).stubs(:value).returns("sparc")
 
-    Facter::Util::Resolution.stubs(:exec).returns(nil)
+    Facter::Util::Resolution.stubs(:exec).with(regexp_matches(/prtdiag/)).returns(nil)
     Facter::Manufacturer.prtdiag_sparc_find_system_info()
     Facter.value(:manufacturer).should_not == "Sun Microsystems"
   end
@@ -122,6 +123,16 @@ Handle 0x001F
     Facter.value(:ramlocation).should == "System Board Or Motherboard"
   end
 
+  it "should return an appropriate uuid on linux" do
+    Facter.fact(:kernel).stubs(:value).returns("Linux")
+    dmidecode = my_fixture_read("intel_linux_dmidecode")
+    Facter::Manufacturer.expects(:get_dmi_table).returns(dmidecode)
+   
+    query = { '[Ss]ystem [Ii]nformation' => [ { 'UUID:' => 'uuid' } ] }
+    Facter::Manufacturer.dmi_find_system_info(query)
+    Facter.value(:uuid).should == "60A98BB3-95B6-E111-AF74-4C72B9247D28"
+  end
+
   def find_product_name(os)
     output_file = case os
       when "FreeBSD" then my_fixture("freebsd_dmidecode")
